# README

## INSTALL

```
pip install pdf2gpkg
```

## USAGE

```
usage: pdf2gpkg [-h] [--loglevel {debug,info,warning,error}] [--version] [--curve-density CURVE_DENSITY] [--page-no PAGE_NO] source_pdf target_dir

positional arguments:
  source_pdf
  target_dir

options:
  -h, --help            show this help message and exit
  --loglevel {debug,info,warning,error}, -l {debug,info,warning,error}
  --version, -v
  --curve-density CURVE_DENSITY, -d CURVE_DENSITY
  --page-no PAGE_NO, -p PAGE_NO
```
